Exec { timeout => 300 }


class {"nova::cert":
    enabled => true,
}


class {"nova::conductor":
    enabled => true,
}

package{'python-cinderclient':
    before => Class["nova"]
}

nova_config{
    "DEFAULT/volume_api_class": value => "nova.volume.cinder.API";
}

class {"nova::compute":
    enabled => true,
    vncproxy_host => "10.35.160.113",
    vncserver_proxyclient_address => "10.35.160.113",
}


# Note : remove this once we're installing a version of openstack that isn't
#        supported on RHEL 6.3
if $::is_virtual_packstack == "true" and $::osfamily == "RedHat" and
    $::operatingsystemrelease == "6.3"{
    file { "/usr/bin/qemu-system-x86_64":
        ensure => link,
        target => "/usr/libexec/qemu-kvm",
        notify => Service["nova-compute"],
    }
}

# Tune the host with a virtual hosts profile
package {'tuned':
    ensure => present,
}

service {'tuned':
    ensure => running,
    require => Package['tuned'],
}

if $::operatingsystem == 'Fedora' and $::operatingsystemrelease == 19 {
    # older tuned service is sometimes stucked on Fedora 19
    exec {'tuned-update':
       path => ['/sbin', '/usr/sbin', '/bin', '/usr/bin'],
       command => 'yum update -y tuned',
       logoutput => 'on_failure',
    }

    exec {'tuned-restart':
       path => ['/sbin', '/usr/sbin', '/bin', '/usr/bin'],
       command => 'systemctl restart tuned.service',
       logoutput => 'on_failure',
    }

    Service['tuned'] -> Exec['tuned-update'] -> Exec['tuned-restart'] -> Exec['tuned-virtual-host']
}

exec {'tuned-virtual-host':
    unless => '/usr/sbin/tuned-adm active | /bin/grep virtual-host',
    command => '/usr/sbin/tuned-adm profile virtual-host',
    require => Service['tuned'],
}
Firewall <| |> -> Class['nova::compute::libvirt']

# Ensure Firewall changes happen before libvirt service start
# preventing a clash with rules being set by libvirt

if $::is_virtual_packstack == "true" {
    $libvirt_type = "qemu"
    nova_config{
        "DEFAULT/libvirt_cpu_mode": value => "none";
    }
}else{
    $libvirt_type = "kvm"
}

nova_config{
  "DEFAULT/libvirt_inject_partition": value => "-1";
}

exec { 'qemu-kvm':
    path => '/usr/bin',
    command => 'yum install -y qemu-kvm',
    before => Class['nova::compute::libvirt']
}

class { 'nova::compute::libvirt':
  libvirt_type                => "$libvirt_type",
  vncserver_listen            => "10.35.160.113",
}

exec {'load_kvm':
    user => 'root',
    command => '/bin/sh /etc/sysconfig/modules/kvm.modules',
    onlyif => '/usr/bin/test -e /etc/sysconfig/modules/kvm.modules',
}

Class['nova::compute']-> Exec["load_kvm"]

file_line { 'libvirt-guests':
    path  => '/etc/sysconfig/libvirt-guests',
    line  => 'ON_BOOT=ignore',
    match => '^[\s#]*ON_BOOT=.*',
    require => Class['nova::compute::libvirt']
}

# Remove libvirt's default network (usually virbr0) as it's unnecessary and can be confusing
exec {'virsh-net-destroy-default':
    onlyif  => '/usr/bin/virsh net-list | grep default',
    command => '/usr/bin/virsh net-destroy default',
    require => Package['libvirt'],
}

exec {'virsh-net-undefine-default':
    onlyif  => '/usr/bin/virsh net-list --inactive | grep default',
    command => '/usr/bin/virsh net-undefine default',
    require => Exec['virsh-net-destroy-default'],
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'nova_compute':
  host => '10.35.160.113',
  service_name => 'nova compute',
  chain => 'INPUT',
  ports => ['5900-5999'],
}



nova_config{
    # OpenStack doesn't include the CoreFilter (= CPU Filter) by default
    "DEFAULT/scheduler_default_filters":
        value => "RetryFilter,AvailabilityZoneFilter,RamFilter,ComputeFilter,ComputeCapabilitiesFilter,ImagePropertiesFilter,CoreFilter";
    "DEFAULT/cpu_allocation_ratio":
        value => "16.0";
    "DEFAULT/ram_allocation_ratio":
        value => "1.5";
}

class {"nova::scheduler":
    enabled => true,
}

class {"nova::vncproxy":
    enabled => true,
}

class {"nova::consoleauth":
    enabled => true,
}

firewall { '001 novncproxy incoming':
    proto    => 'tcp',
    dport    => ['6080'],
    action   => 'accept',
}



class { "nova":
    glance_api_servers => "10.35.160.113:9292",
    rabbit_host        => "10.35.160.113",
    rabbit_port        => '5672',
    rabbit_userid      => 'guest',
    rabbit_password    => 'guest',
    verbose            => true,
    debug              => false,
}

# Ensure Firewall changes happen before nova services start
# preventing a clash with rules being set by nova-compute and nova-network
Firewall <| |> -> Class['nova']

nova_config{
    "DEFAULT/sql_connection": value => "mysql://nova:qum5net@10.35.160.113/nova";
    "DEFAULT/metadata_host": value => "10.35.160.113";
}




nova_config {
    "DEFAULT/default_floating_pool": value => 'nova';
    "DEFAULT/auto_assign_floating_ip": value => 'False';
}

$multihost = false
if $multihost {
    nova_config {
        "DEFAULT/multi_host": value => true;
        "DEFAULT/send_arp_for_ha": value => true;
    }
}

$manager = 'nova.network.manager.FlatDHCPManager'
$overrides = {}
if $manager in ['nova.network.manager.VlanManager', 'nova.network.manager.FlatDHCPManager'] {
    $overrides['force_dhcp_release'] = false
}
if $manager == 'nova.network.manager.VlanManager' {
    $overrides['vlan_start'] = '100'
    $net_size = '255'
    $net_num = '1'
} else {
    $net_size = '1024'
    $net_num = 1
}
class { "nova::network":
    enabled => true,
    network_manager => $manager,
    num_networks => $net_num ,
    network_size => $net_size,
    private_interface => 'enp2s0f1',
    public_interface => 'enp2s0f0',
    fixed_range => '192.168.32.0/22',
    floating_range => '10.3.4.0/22',
    config_overrides => $overrides,
}

package { 'dnsmasq': ensure => present }
